@@ -14,7 +14,7 @@ use Time::HiRes qw(gettimeofday);
 
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 push @ISA, 'Exporter'; @EXPORT_OK = qw(run print_results);
 
@@ -150,7 +150,16 @@ sub run {
                 no strict 'refs';
                 my @resultkeys = split(/::/);
                 print STDERR "# Run $_...\n" if $verbose;
-                my $res = &{"Benchmark::Perl::Formance::Plugin::${_}::main"}($options);
+                my $res;
+                eval {
+                        $res = &{"Benchmark::Perl::Formance::Plugin::${_}::main"}($options);
+                };
+                if ($@) {
+                        $res = {
+                                failed => "Plugin $_ failed",
+                                error  => $@,
+                               }
+                }
                 eval "\$RESULTS{results}{".join("}{", @resultkeys)."} = \$res";
         }
         my $after  = gettimeofday();
